integrators.ode package
===========================

.. currentmodule:: integrators.ode
.. automodule:: integrators.ode

.. contents::
    :local:
    :depth: 1




Runge-Kutta methods
--------------------


.. autosummary::
    :toctree: _autosummary

    euler
    heun2
    heun3
    midpoint
    ralston2
    ralston3
    ralston4
    rk2
    rk3
    rk4
    rk4_38rule
    ssprk3


Adaptive methods
----------------

.. autosummary::
    :toctree: _autosummary

    bs
    ck
    rkdp
    rkf45


Other methods
-------------

.. autosummary::
    :toctree: _autosummary

    exponential_euler

